#' Fm data
#'
#'
#' @format ## `Fm`
#' A data frame with 9 rows and 15 columns:
#' \describe{
#'   \item{chl_c1}{XX}
#'   \item{Per}{XX}
#'   \item{X19but}{XX}
#'   ...
#' }
#' @source XX
"Fm"


#' Sm data
#'
#'
#' @format ## `Sm`
#' A data frame with 29 rows and 15 columns:
#' \describe{
#'   \item{chl_c1}{XX}
#'   \item{Per}{XX}
#'   \item{X19but}{XX}
#'   ...
#' }
#' @source XX
"Sm"


#' Fp data
#'
#'
#' @format ## `Fp`
#' A data frame with 9 rows and 15 columns:
#' \describe{
#'   \item{chl_c1}{XX}
#'   \item{Per}{XX}
#'   \item{X19but}{XX}
#'   ...
#' }
#' @source XX
"Fp"


#' Sp data
#'
#'
#' @format ## `Sp`
#' A data frame with 29 rows and 15 columns:
#' \describe{
#'   \item{chl_c1}{XX}
#'   \item{Per}{XX}
#'   \item{X19but}{XX}
#'   ...
#' }
#' @source XX
"Sp"


#' min_max data
#'
#'
#' @format ## `min_max`
#' A data frame with 76 rows and 4 columns:
#' \describe{
#'   \item{class}{XX}
#'   \item{Pig_Abbrev}{XX}
#'   \item{min}{XX}
#'   \item{max}{max}
#'   ...
#' }
#' @source XX
"min_max"





